package Data::Filter::Rule::Atom;
use strict;
use warnings;

#*******************************************************************************
# DOCUMENTATION SECTION
#*******************************************************************************

=head1 NAME

Data::Filter::Rule::Atom - Mentat message filter tree terminal node

=head1 SYNOPSIS

 use Data::Filter::Rule::Atom;

=head1 DESCRIPTION



=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.


=head1 SEE ALSO

perl(1), Data::Filter::Rule(3).

=head1 FUNCTION REFERENCE

=over 4

=cut

#*******************************************************************************
# LIBRARY LOADING SECTION
#*******************************************************************************

#-- Perl core modules ---------------------------------------------------------#
use Carp;
use Scalar::Util 'blessed';

#use Data::Dumper; #--- DEVELOPMENT ONLY ---#
#use Smart::Comments; #--- DEVELOPMENT ONLY ---#

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#
use Data::Filter::Rule;

#*******************************************************************************
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#*******************************************************************************

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

#*******************************************************************************
# INITIALIZATION AND CLEANUP SECTION
#*******************************************************************************

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION $DEVEL @ISA);
    $VERSION = '0.1';
    $DEVEL   = 0;
    @ISA     = ('Data::Filter::Rule');
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

#*******************************************************************************
# IMPLEMENTATION SECTION
#*******************************************************************************

=item operation() [PUBLIC, ABSTRACT]

  Usage     : my $result = $rule->operation();
  Purpose   :
  Returns   :
  Arguments :
  Throws    :
  Comments  :
  See Also  :

=cut

sub operation()
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);

    return undef;
}

#-------------------------------------------------------------------------------

=item traverse($;@) [PUBLIC]

  Usage     : my $result = Data::Filter::Rule->traverse($traverser);
  Purpose   : Traversal through the filter rule tree with given traverser object
  Returns   :
  Arguments :
  Throws    :
  Comments  :
  See Also  :

=cut

sub traverse($;@)
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);
    my ($traverser, @args) = @_;
    confess "Traverser object must be given as first argument" unless ref $traverser;

    my $name = lcfirst($self->name());
    confess "Traverser object can`t handle '$name' callback hook" unless $traverser->can($name);

    return $traverser->$name($self, @args);
}

=pod

=back

=cut

1;
